==> huaweicloudsdkidentitycenter-3.1.127-py2.py3-none-any.whl: huaweicloudsdkidentitycenter/v1/model/create_instance_access_control_attribute_configuration_req_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateInstanceAccessControlAttributeConfigurationReqBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_access_control_attribute_configuration': 'InstanceAccessControlAttributeConfigurationDto'
    }

    attribute_map = {
        'instance_access_control_attribute_configuration': 'instance_access_control_attribute_configuration'
    }

    def __init__(self, instance_access_control_attribute_configuration=None):
        """CreateInstanceAccessControlAttributeConfigurationReqBody

        The model defined in huaweicloud sdk

        :param instance_access_control_attribute_configuration: 
        :type instance_access_control_attribute_configuration: :class:`huaweicloudsdkidentitycenter.v1.InstanceAccessControlAttributeConfigurationDto`
        """
        
        

        self._instance_access_control_attribute_configuration = None
        self.discriminator = None

        self.instance_access_control_attribute_configuration = instance_access_control_attribute_configuration

    @property
    def instance_access_control_attribute_configuration(self):
        """Gets the instance_access_control_attribute_configuration of this CreateInstanceAccessControlAttributeConfigurationReqBody.

        :return: The instance_access_control_attribute_configuration of this CreateInstanceAccessControlAttributeConfigurationReqBody.
        :rtype: :class:`huaweicloudsdkidentitycenter.v1.InstanceAccessControlAttributeConfigurationDto`
        """
        return self._instance_access_control_attribute_configuration

    @instance_access_control_attribute_configuration.setter
    def instance_access_control_attribute_configuration(self, instance_access_control_attribute_configuration):
        """Sets the instance_access_control_attribute_configuration of this CreateInstanceAccessControlAttributeConfigurationReqBody.

        :param instance_access_control_attribute_configuration: The instance_access_control_attribute_configuration of this CreateInstanceAccessControlAttributeConfigurationReqBody.
        :type instance_access_control_attribute_configuration: :class:`huaweicloudsdkidentitycenter.v1.InstanceAccessControlAttributeConfigurationDto`
        """
        self._instance_access_control_attribute_configuration = instance_access_control_attribute_configuration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateInstanceAccessControlAttributeConfigurationReqBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkidentitycenter-3.1.145-py2.py3-none-any.whl: huaweicloudsdkidentitycenter/v1/model/create_instance_access_control_attribute_configuration_req_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateInstanceAccessControlAttributeConfigurationReqBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_access_control_attribute_configuration': 'InstanceAccessControlAttributeConfigurationDto'
    }

    attribute_map = {
        'instance_access_control_attribute_configuration': 'instance_access_control_attribute_configuration'
    }

    def __init__(self, instance_access_control_attribute_configuration=None):
        r"""CreateInstanceAccessControlAttributeConfigurationReqBody

        The model defined in huaweicloud sdk

        :param instance_access_control_attribute_configuration: 
        :type instance_access_control_attribute_configuration: :class:`huaweicloudsdkidentitycenter.v1.InstanceAccessControlAttributeConfigurationDto`
        """
        
        

        self._instance_access_control_attribute_configuration = None
        self.discriminator = None

        self.instance_access_control_attribute_configuration = instance_access_control_attribute_configuration

    @property
    def instance_access_control_attribute_configuration(self):
        r"""Gets the instance_access_control_attribute_configuration of this CreateInstanceAccessControlAttributeConfigurationReqBody.

        :return: The instance_access_control_attribute_configuration of this CreateInstanceAccessControlAttributeConfigurationReqBody.
        :rtype: :class:`huaweicloudsdkidentitycenter.v1.InstanceAccessControlAttributeConfigurationDto`
        """
        return self._instance_access_control_attribute_configuration

    @instance_access_control_attribute_configuration.setter
    def instance_access_control_attribute_configuration(self, instance_access_control_attribute_configuration):
        r"""Sets the instance_access_control_attribute_configuration of this CreateInstanceAccessControlAttributeConfigurationReqBody.

        :param instance_access_control_attribute_configuration: The instance_access_control_attribute_configuration of this CreateInstanceAccessControlAttributeConfigurationReqBody.
        :type instance_access_control_attribute_configuration: :class:`huaweicloudsdkidentitycenter.v1.InstanceAccessControlAttributeConfigurationDto`
        """
        self._instance_access_control_attribute_configuration = instance_access_control_attribute_configuration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateInstanceAccessControlAttributeConfigurationReqBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
